==> haskell-wl-pprint-terminfo-3.7.1.4-112-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-5FMHG4fFR1H3fnGIApZZPo
key: wl-pprint-terminfo-3.7.1.4-5FMHG4fFR1H3fnGIApZZPo
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: cf1aa610d927b1d3d57f03cbdd6424f3
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-5FMHG4fFR1H3fnGIApZZPo
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.6.2
    wl-pprint-extras-3.5.0.5-BUlgES7Px5gEUTgf9rFOrB
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-terminfo-3.7.1.4-113-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-terminfo.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-terminfo
version: 3.7.1.4
id: wl-pprint-terminfo-3.7.1.4-3wTFYeSAB53DoXBSELKhRG
key: wl-pprint-terminfo-3.7.1.4-3wTFYeSAB53DoXBSELKhRG
license: BSD-3-Clause
copyright: Copyright (C) 2011 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/wl-pprint-terminfo/
synopsis: A color pretty printer with terminfo support
description:
    A color pretty printer with terminfo support
category: Control, Monads, Text
abi: f4e6e05f5f09fbdecc1944a4ee0f030b
exposed: True
exposed-modules:
    System.Console.Terminfo.PrettyPrint
hidden-modules: System.Console.Terminfo.PrettyPrint.Curses
import-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/wl-pprint-terminfo-3.7.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-wl-pprint-terminfo
hs-libraries: HSwl-pprint-terminfo-3.7.1.4-3wTFYeSAB53DoXBSELKhRG
extra-libraries:
    ncursesw
includes:
    cursed.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    terminfo-0.4.1.2 text-1.2.3.1 transformers-0.5.6.2
    wl-pprint-extras-3.5.0.5-C4enrGG8ddJJcW34b7TyQu
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-terminfo/html/wl-pprint-terminfo.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-terminfo/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
